diff Core/HttpServer/EmbeddedResourceHttpHandler.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children 2d96cb181f45
line wrap: on
line diff
--- a/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,12 +20,12 @@
 
 #include "EmbeddedResourceHttpHandler.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <stdio.h>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   EmbeddedResourceHttpHandler::EmbeddedResourceHttpHandler(
     const std::string& baseUri,
@@ -65,9 +65,9 @@
       size_t size = EmbeddedResources::GetDirectoryResourceSize(resourceId_, resourcePath.c_str());
       output.AnswerBufferWithContentType(buffer, size, contentType);
     }
-    catch (PalanthirException& e)
+    catch (OrthancException& e)
     {
-      output.SendHeader(Palanthir_HttpStatus_404_NotFound);
+      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
     }
   } 
 }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium